Task: SQuAD
============
Description: Open-domain QA dataset answerable from a given paragraph from Wikipedia, from Rajpurkar et al. '16. 

Link: https://arxiv.org/abs/1606.05250

Tags: #SQuAD, #All, #QA

